Crate obel_reflect_utils

Obel Reflect Utils

license crates.io downloads docs.rs discord.online

A collection of helper types and functions for working on macros within the Bevy ecosystem.

Structs

FQAny
Fully Qualified (FQ) short name for std::any::Any
FQBox
Fully Qualified (FQ) short name for Box
FQClone
Fully Qualified (FQ) short name for Clone
FQDefault
Fully Qualified (FQ) short name for Default
FQOption
Fully Qualified (FQ) short name for Option
FQResult
Fully Qualified (FQ) short name for Result
FQSend
Fully Qualified (FQ) short name for Send
FQSync
Fully Qualified (FQ) short name for Sync
ObelManifest
The path to the Cargo.toml file for the Bevy project.
Symbol
A single named value, representable as a string.

Functions

derive_label
Derive a label trait
ensure_no_collision
Finds an identifier that will not conflict with the specified set of tokens.
get_lit_bool
Get a literal boolean from the provided expression as a bool.
get_lit_str
Get a literal string from the provided expression.
get_struct_fields
Get the fields of a data structure if that structure is a struct with named fields; otherwise, return a compile error that points to the site of the macro invocation.